@@ -4,6 +4,8 @@ require 'rspec/expectations'
 require 'aruba'
 require 'aruba/config'
 
+Dir.glob( File.join( File.expand_path( '../matchers' , __FILE__ )  , '*.rb' ) ).each { |rb| require rb }
+
 module Aruba
   module Api
     include RSpec::Matchers
@@ -13,6 +15,11 @@ module Aruba
       Dir.chdir(current_dir, &block)
     end
 
+    def clean_current_dir
+      _rm_rf(current_dir)
+      _mkdir(current_dir)
+    end
+
     def current_dir
       File.join(*dirs)
     end
@@ -46,6 +53,23 @@ module Aruba
       end
     end
 
+    def chmod(mode, name)
+      in_current_dir do
+        raise "expected #{name} to be present" unless FileTest.exists?(name)
+        if mode.kind_of? String
+          FileUtils.chmod(mode.to_i(8),name)
+        else
+          FileUtils.chmod(mode,name)
+        end
+      end
+    end
+
+    def mod?(mode, name)
+      in_current_dir do
+        mode == sprintf( "%o", File::Stat.new(name).mode )[-4,4].to_i(8)
+      end
+    end
+
     def _create_fixed_size_file(file_name, file_size, check_presence)
       in_current_dir do
         raise "expected #{file_name} to be present" if check_presence && !File.file?(file_name)
@@ -82,25 +106,41 @@ module Aruba
     def check_file_presence(paths, expect_presence)
       prep_for_fs_check do
         paths.each do |path|
-          if expect_presence
-            File.should be_file(path)
+          if path.kind_of? Regexp
+            if expect_presence
+              expect(Dir.glob('**/*')).to include_regexp(path)
+            else
+              expect(Dir.glob('**/*')).not_to include_regexp(path)
+            end
           else
-            File.should_not be_file(path)
+            if expect_presence
+              expect(File).to be_file(path)
+            else
+              expect(File).not_to be_file(path)
+            end
           end
         end
       end
     end
 
+    def pipe_in_file(file)
+      in_current_dir do
+        File.open(file, 'r').each_line do |line|
+          _write_interactive(line)
+        end
+      end
+    end
+
     def check_file_size(paths_and_sizes)
       prep_for_fs_check do
         paths_and_sizes.each do |path, size|
-          File.size(path).should == size
+          expect(File.size(path)).to eq size
         end
       end
     end
 
     def with_file_content(file, &block)
-      prep_for_fs_check do 
+      prep_for_fs_check do
         content = IO.read(file)
         yield(content)
       end
@@ -108,27 +148,27 @@ module Aruba
 
     def check_file_content(file, partial_content, expect_match)
       regexp = regexp(partial_content)
-      prep_for_fs_check do 
+      prep_for_fs_check do
         content = IO.read(file)
         if expect_match
-          content.should =~ regexp
+          expect(content).to match regexp
         else
-          content.should_not =~ regexp
+          expect(content).not_to match regexp
         end
       end
     end
 
     def check_exact_file_content(file, exact_content)
-      prep_for_fs_check { IO.read(file).should == exact_content }
+      prep_for_fs_check { expect(IO.read(file)).to eq exact_content }
     end
 
     def check_directory_presence(paths, expect_presence)
       prep_for_fs_check do
         paths.each do |path|
           if expect_presence
-            File.should be_directory(path)
+            expect(File).to be_directory(path)
           else
-            File.should_not be_directory(path)
+            expect(File).not_to be_directory(path)
           end
         end
       end
@@ -143,6 +183,10 @@ module Aruba
       FileUtils.mkdir_p(dir_name) unless File.directory?(dir_name)
     end
 
+    def _rm_rf(dir_name)
+      FileUtils.rm_rf(dir_name)
+    end
+
     def unescape(string)
       string = string.gsub('\n', "\n").gsub('\"', '"').gsub('\e', "\e")
       string = string.gsub(/\e\[\d+(?>(;\d+)*)m/, '') unless @aruba_keep_ansi
@@ -184,30 +228,30 @@ module Aruba
 
     def assert_exact_output(expected, actual)
       actual.force_encoding(expected.encoding) if RUBY_VERSION >= "1.9"
-      unescape(actual).should == unescape(expected)
+      expect(unescape(actual)).to eq unescape(expected)
     end
 
     def assert_partial_output(expected, actual)
       actual.force_encoding(expected.encoding) if RUBY_VERSION >= "1.9"
-      unescape(actual).should include(unescape(expected))
+      expect(unescape(actual)).to include(unescape(expected))
     end
 
     def assert_matching_output(expected, actual)
       actual.force_encoding(expected.encoding) if RUBY_VERSION >= "1.9"
-      unescape(actual).should =~ /#{unescape(expected)}/m
+      expect(unescape(actual)).to match /#{unescape(expected)}/m
     end
 
     def assert_not_matching_output(expected, actual)
       actual.force_encoding(expected.encoding) if RUBY_VERSION >= "1.9"
-      unescape(actual).should_not =~ /#{unescape(expected)}/m
+      expect(unescape(actual)).not_to match /#{unescape(expected)}/m
     end
 
     def assert_no_partial_output(unexpected, actual)
       actual.force_encoding(unexpected.encoding) if RUBY_VERSION >= "1.9"
       if Regexp === unexpected
-        unescape(actual).should_not =~ unexpected
+        expect(unescape(actual)).not_to match unexpected
       else
-        unescape(actual).should_not include(unexpected)
+        expect(unescape(actual)).not_to include(unexpected)
       end
     end
 
@@ -243,12 +287,12 @@ module Aruba
     end
 
     def assert_exit_status(status)
-      last_exit_status.should eq(status),
+      expect(last_exit_status).to eq(status),
         append_output_to("Exit status was #{last_exit_status} but expected it to be #{status}.")
     end
 
     def assert_not_exit_status(status)
-      last_exit_status.should_not eq(status),
+      expect(last_exit_status).not_to eq(status),
         append_output_to("Exit status was #{last_exit_status} which was not expected.")
     end
 
@@ -278,7 +322,9 @@ module Aruba
     end
 
     def get_process(wanted)
-      processes.reverse.find{ |name, _| name == wanted }[-1]
+      matching_processes = processes.reverse.find{ |name, _| name == wanted }
+      raise ArgumentError.new("No process named '#{wanted}' has been started") unless matching_processes
+      matching_processes.last
     end
 
     def only_processes
@@ -331,14 +377,19 @@ module Aruba
     end
 
     def type(input)
-      return eot if "" == input
+      return close_input if "" == input
       _write_interactive(_ensure_newline(input))
     end
 
-    def eot
+    def close_input
       @interactive.stdin.close
     end
 
+    def eot
+      warn(%{\e[35m    The \"#eot\"-method is deprecated. It will be deleted with the next major version. Please use \"#close_input\"-method instead.\e[0m})
+      close_input
+    end
+
     def _write_interactive(input)
       @interactive.stdin.write(input)
       @interactive.stdin.flush
@@ -430,8 +481,8 @@ module Aruba
     end
 
     def announcer
-      Announcer.new(self, 
-                    :stdout => @announce_stdout, 
+      Announcer.new(self,
+                    :stdout => @announce_stdout,
                     :stderr => @announce_stderr,
                     :dir => @announce_dir,
                     :cmd => @announce_cmd,
