@@ -40,4 +40,11 @@ RSpec.configure do |config|
   config.run_all_when_everything_filtered = true
   config.treat_symbols_as_metadata_keys_with_true_values = true
   config.include(ManipulatesConstants)
+  config.expect_with :rspec do |c|
+    c.syntax = :expect
+  end
+
+  config.before( :each ) {
+    clean_current_dir
+  }
 end
